# coordIO

[![Versions](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue)](https://docs.python.org/3/)
[![Documentation Status](https://readthedocs.org/projects/sdss-coordio/badge/?version=latest)](https://sdss-coordio.readthedocs.io/en/latest/?badge=latest)
[![Tests Status](https://github.com/sdss/coordio/workflows/Test/badge.svg)](https://github.com/sdss/coordio/actions)
[![Coverage Status](https://codecov.io/gh/sdss/coordio/branch/master/graph/badge.svg)](https://codecov.io/gh/sdss/coordio)


Coordinate conversion for SDSS-V.


## Installation

In general you should be able to install ``coordio`` by doing

```console
pip install sdss-coordio
```

To build from source, use

```console
git clone git@github.com:sdss/coordio
cd coordio
pip install .
```
